@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2017-01-16'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2017-07-07'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -213,8 +213,8 @@ sub munge_files {
     }
 
     my $fileobj = Dist::Zilla::File::InMemory->new(
-        name => "bin/$scriptname", content => $res->[2]);
-    $self->log(["Creating script 'bin/%s' from Riap function '%s'", $scriptname, $self->url]);
+        name => "script/$scriptname", content => $res->[2]);
+    $self->log(["Creating script 'script/%s' from Riap function '%s'", $scriptname, $self->url]);
     $self->add_file($fileobj);
 
     # create a separate completion script if we use Perinci::CmdLine::Inline,
@@ -235,8 +235,8 @@ sub munge_files {
         $self->log_fatal("Failed generating completer script _$scriptname: $compres->[0] - $compres->[1]")
             unless $compres->[0] == 200;
         my $compfileobj = Dist::Zilla::File::InMemory->new(
-            name => "bin/_$scriptname", content => $compres->[2]);
-        $self->log(["Creating completer script 'bin/_%s' from Riap function '%s'", $scriptname, $self->url]);
+            name => "script/_$scriptname", content => $compres->[2]);
+        $self->log(["Creating completer script 'script/_%s' from Riap function '%s'", $scriptname, $self->url]);
         $self->add_file($compfileobj);
     }
 }
@@ -258,22 +258,22 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.40 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-16.
+This document describes version 0.41 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-07-07.
 
 =head1 SYNOPSIS
 
 In F<dist.ini>:
 
- ; generate a script, by default called bin/check-palindrome
+ ; generate a script, by default called script/check-palindrome
  [GenPericmdScript]
  url=/My/Palindrome/check_palindrome
 
- ; generate another script, called bin/lssrv
+ ; generate another script, called script/lssrv
  [GenPericmdScript / Gen_lssrv]
  url=/My/App/list_servers
  name=lssrv
 
-After build, C<bin/check-palindrome> and C<bin/lssrv> will be created.
+After build, C<script/check-palindrome> and C<script/lssrv> will be created.
 
 =head1 DESCRIPTION
 
@@ -444,8 +444,8 @@ Will be passed to Perinci::CmdLine::Gen backend.
 
 Perinci::CmdLine::Inline-generated scripts currently cannot do shell completion
 on its own, but relies on a separate completer script (e.g. if the script is
-C<bin/foo> then the completer will be generated at C<bin/_foo>). This option can
-be used to suppress the generation of completer script.
+C<script/foo> then the completer will be generated at C<script/_foo>). This
+option can be used to suppress the generation of completer script.
 
 =head2 build_load_modules => array[str]
 
@@ -457,7 +457,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
 
 =head1 BUGS
 
@@ -482,7 +482,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
